@@ -75,26 +75,28 @@ def get_remote_files(dataset, filenames):
     return remote_files
 
 
-def _resolve_annotation_classes(annotation_classes: List[dt.AnnotationClass], classes_in_dataset, classes_in_team):
-    local_classes_not_in_dataset = set()
-    local_classes_not_in_team = set()
+def _resolve_annotation_classes(
+    local_annotation_classes: List[dt.AnnotationClass], classes_in_dataset, classes_in_team
+):
+    local_classes_not_in_dataset: set[dt.AnnotationClass] = set()
+    local_classes_not_in_team: set[dt.AnnotationClass] = set()
 
-    for cls in annotation_classes:
-        annotation_type = cls.annotation_internal_type or cls.annotation_type
+    for local_cls in local_annotation_classes:
+        local_annotation_type = local_cls.annotation_internal_type or local_cls.annotation_type
         # Only add the new class if it doesn't exist remotely already
-        if annotation_type in classes_in_dataset and cls.name in classes_in_dataset[annotation_type]:
+        if local_annotation_type in classes_in_dataset and local_cls.name in classes_in_dataset[local_annotation_type]:
             continue
 
         # Only add the new class if it's not included in the list of the missing classes already
-        if cls.name in [missing_class.name for missing_class in local_classes_not_in_dataset]:
+        if local_cls.name in [missing_class.name for missing_class in local_classes_not_in_dataset]:
             continue
-        if cls.name in [missing_class.name for missing_class in local_classes_not_in_team]:
+        if local_cls.name in [missing_class.name for missing_class in local_classes_not_in_team]:
             continue
 
-        if annotation_type in classes_in_team and cls.name in classes_in_team[annotation_type]:
-            local_classes_not_in_dataset.add(cls)
+        if local_annotation_type in classes_in_team and local_cls.name in classes_in_team[local_annotation_type]:
+            local_classes_not_in_dataset.add(local_cls)
         else:
-            local_classes_not_in_team.add(cls)
+            local_classes_not_in_team.add(local_cls)
     return local_classes_not_in_dataset, local_classes_not_in_team
 
 
@@ -103,7 +105,26 @@ def import_annotations(
     importer: Callable[[Path], Union[List[dt.AnnotationFile], dt.AnnotationFile, None]],
     file_paths: List[Union[str, Path]],
     append: bool,
-):
+) -> None:
+    """
+    Imports the given given Annotations into the given Dataset.
+
+    Parameters
+    ----------
+    dataset : RemoteDataset
+        Dataset where the Annotations will be imported to.
+    importer : Callable[[Path], Union[List[dt.AnnotationFile], dt.AnnotationFile, None]]
+        Parsing module containing the logic to parse the given Annotation files given in 
+        `files_path`. See `importer/format` for a list of out of supported parsers.
+    file_paths : List[Union[str, Path]],
+        A list of `Path`s or strings containing the Annotations we wish to import.
+    append : bool
+        If `True` appends the given annotations to the datasets. If `False` will override them.
+    
+    Returns
+        -------
+        None
+    """
     print("Fetching remote class list...")
     team_classes = dataset.fetch_remote_classes(True)
     classes_in_dataset = build_main_annotations_lookup_table([cls for cls in team_classes if cls["available"]])
